@@ -27,4 +27,8 @@ class WialonRoute(WialonBase):
                 "dataFlags": flags.DATAFLAG_UNIT_BASE,
             }
         )
-        return int(response.get("item", {}).get("id")) if response.get("item") else None
+        return (
+            int(response.get("item", {}).get("id"))
+            if response and response.get("item")
+            else None
+        )
